@@ -4,7 +4,7 @@
 # Copyright 2010 K. Richard Pixley.
 # See LICENSE for details.
 #
-# Time-stamp: <23-Feb-2010 17:18:50 PST by rich@noir.com>
+# Time-stamp: <25-Feb-2010 07:38:03 PST by rich@noir.com>
 
 """
 This module subclasses the MetaSerializer object into two distinct
@@ -12,9 +12,11 @@ subclasses both of which are based on the pickle module from the
 standard library.
 """
 
+from __future__ import unicode_literals
+
 __docformat__ = 'epytext'
 
-from metaserializer import MetaSerializer
+from metaserializer import MetaSerializer, _register
 
 try:
     import cPickle as pickle
@@ -28,6 +30,7 @@ class PickleDefault(MetaSerializer):
     """
 
     name = 'pickledefault'
+    magic = b'a'
     _protocol = 0
 
     def dump(self, object, file):
@@ -36,11 +39,12 @@ class PickleDefault(MetaSerializer):
     def load(self, file):
         return pickle.load(file)
 
-    def dumps(self, object):
+    def dumpb(self, object):
         return pickle.dumps(object, self._protocol)
 
-    def loads(self, string):
-        return pickle.loads(string)
+    def loadb(self, b):
+        assert isinstance(b, bytes)
+        return pickle.loads(b)
 
 
 class PickleHighest(PickleDefault):
@@ -49,4 +53,8 @@ class PickleHighest(PickleDefault):
     used with it's highest available protocol.
     """
     name = 'picklehighest'
+    magic = b'b'
     _protocol = pickle.HIGHEST_PROTOCOL
+
+_register(PickleDefault)
+_register(PickleHighest)
