@@ -4,16 +4,18 @@
 # Copyright 2010 K. Richard Pixley.
 # See LICENSE for details.
 #
-# Time-stamp: <23-Feb-2010 17:37:00 PST by rich@noir.com>
+# Time-stamp: <25-Feb-2010 07:42:21 PST by rich@noir.com>
 
 """
 This module subclasses the MetaSerializer object into a yaml
 serializer based on PyYAML.
 """
 
+from __future__ import unicode_literals
+
 __docformat__ = 'epytext'
 
-from metaserializer import MetaSerializer
+from metaserializer import MetaSerializer, _register
 
 import yaml
 try:
@@ -27,6 +29,7 @@ class YAML(MetaSerializer):
     This serializer is based on U{PyYAML<http://pypi.python.org/pypi/PyYAML>}.
     """
     name = 'yaml'
+    magic = b'c'
 
     def dump(self, object, file):
         yaml.dump(object, file, Dumper=Dumper)
@@ -34,8 +37,10 @@ class YAML(MetaSerializer):
     def load(self, file):
         return yaml.load(file, Loader=Loader)
 
-    def dumps(self, object):
-        return yaml.dump(object, Dumper=Dumper)
+    def dumpb(self, object):
+        return bytes(yaml.dump(object, Dumper=Dumper))
 
-    def loads(self, string):
-        return yaml.load(string, Loader=Loader)
+    def loadb(self, b):
+        return yaml.load(b, Loader=Loader)
+
+_register(YAML)
